pub enum Error {
InvalidHash,
InvalidEccCurve,
InvalidEccParameters,
InvalidRsaParameters,
KeyIsEmpty,
OperationFailed,
OutOfMemory,
PermissionDenied,
}Expand description
The top-level error type for cryptographic operations.
Variants
InvalidHash
Hash algorithm is not supported in the context of use.
InvalidEccCurve
ECC curve is not supported in the context of use.
InvalidEccParameters
Invalid ECC public parameters.
InvalidRsaParameters
Invalid RSA public parameters.
KeyIsEmpty
A zero-length key was provided.
OperationFailed
A cryptographic operation failed.
OutOfMemory
Not enough memory available.
PermissionDenied
The provided HMAC does not match to the expected value.