pub enum TpmCryptoError {
InvalidEccCurve,
InvalidEccParameters,
InvalidHash,
InvalidKeyBits(u16),
InvalidObjectType,
InvalidRsaParameters,
KeyIsEmpty,
Marshal(TpmProtocolError),
OperationFailed,
OutOfMemory,
PermissionDenied,
Unmarshal(TpmProtocolError),
}Expand description
The top-level error type for cryptographic operations.
Variants
InvalidEccCurve
ECC curve is not supported in the context of use.
InvalidEccParameters
Invalid ECC public parameters.
InvalidHash
Hash algorithm is not supported in the context of use.
InvalidKeyBits(u16)
Invalid RSA key bits.
InvalidObjectType
Invalid object type.
InvalidRsaParameters
Invalid RSA public parameters.
KeyIsEmpty
A zero-length key was provided.
Marshal(TpmProtocolError)
Marshaling a TPM protocol encoded object failed.
OperationFailed
A cryptographic operation failed.
OutOfMemory
Not enough memory available.
PermissionDenied
The provided HMAC does not match to the expected value.
Unmarshal(TpmProtocolError)
Unmarshaling a TPM protocol encoded object failed.